@@ -3,6 +3,7 @@ from click_option_group import MutuallyExclusiveOptionGroup, optgroup
 
 from apigee import console
 from apigee.apis.apis import Apis
+from apigee.apis.pull import PullApis
 from apigee.apis.deploy import deploy as deploy_tool
 from apigee.auth import common_auth_options, gen_auth
 from apigee.prefix import common_prefix_options
@@ -12,14 +13,23 @@ from apigee.verbose import common_verbose_options
 
 
 @click.group(
-    help='The proxy APIs let you perform operations on API proxies, such as create, delete, update, and deploy.'
+    help="The proxy APIs let you perform operations on API proxies, such as create, delete, update, and deploy."
 )
 def apis():
     pass
 
 
 def _delete_api_proxy_revision(
-    username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    revision_number,
+    **kwargs,
 ):
     return (
         Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -29,13 +39,15 @@ def _delete_api_proxy_revision(
 
 
 @apis.command(
-    help='Deletes a revision of an API proxy and all policies, resources, endpoints, and revisions associated with it. The API proxy revision must be undeployed before you can delete it.'
+    help="Deletes a revision of an API proxy and all policies, resources, endpoints, and revisions associated with it. The API proxy revision must be undeployed before you can delete it."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option(
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
 def delete_revision(*args, **kwargs):
     console.echo(_delete_api_proxy_revision(*args, **kwargs))
 
@@ -65,22 +77,24 @@ def _deploy_api_proxy_revision(
 
 
 @apis.command(
-    help='Deploys a revision of an existing API proxy to an environment in an organization.'
+    help="Deploys a revision of an existing API proxy to an environment in an organization."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-e', '--environment', help='environment', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option("-e", "--environment", help="environment", required=True)
 @click.option(
-    '--delay',
-    type=click.INT,
-    default=0,
-    help='Enforces a delay, measured in seconds, before the currently deployed API proxy revision is undeployed and replaced by the new revision that is being deployed. Use this setting to minimize the impact of deployment on in-flight transactions. The default value is 0.',
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
 )
 @click.option(
-    '--override/--no-override',
+    "--delay",
+    type=click.INT,
+    default=0,
+    help="Enforces a delay, measured in seconds, before the currently deployed API proxy revision is undeployed and replaced by the new revision that is being deployed. Use this setting to minimize the impact of deployment on in-flight transactions. The default value is 0.",
+)
+@click.option(
+    "--override/--no-override",
     default=False,
     help='Flag that specifies whether to use seamless deployment to ensure zero downtime. Set this flag to "true" to instruct Edge to deploy the new revision fully before undeploying the existing revision. Use in conjunction with the delay parameter to control when the existing revision is undeployed.',
 )
@@ -107,20 +121,22 @@ def _delete_undeployed_revisions(
 
 
 @apis.command(
-    help='Deletes all undeployed revisions of an API proxy and all policies, resources, endpoints, and revisions associated with it.'
+    help="Deletes all undeployed revisions of an API proxy and all policies, resources, endpoints, and revisions associated with it."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-n", "--name", help="name", required=True)
 @click.option(
-    '--save-last',
+    "--save-last",
     type=click.INT,
-    help='denotes not to delete the N most recent revisions',
+    help="denotes not to delete the N most recent revisions",
     default=0,
 )
 @click.option(
-    '--dry-run/--no-dry-run', default=False, help='show revisions to be deleted but do not delete'
+    "--dry-run/--no-dry-run",
+    default=False,
+    help="show revisions to be deleted but do not delete",
 )
 def clean(*args, **kwargs):
     _delete_undeployed_revisions(*args, **kwargs)
@@ -140,30 +156,39 @@ def _export_api_proxy(
     output_file=None,
     **kwargs,
 ):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).export_api_proxy(
+    return Apis(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).export_api_proxy(
         name,
         revision_number,
         fs_write=True,
-        output_file=output_file if output_file else f'{name}.zip',
+        output_file=output_file if output_file else f"{name}.zip",
     )
 
 
 @apis.command(
-    help='Outputs an API proxy revision as a ZIP formatted bundle of code and config files. This enables local configuration and development, including attachment of policies and scripts.'
+    help="Outputs an API proxy revision as a ZIP formatted bundle of code and config files. This enables local configuration and development, including attachment of policies and scripts."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
+@click.option("-n", "--name", help="name", required=True)
 @click.option(
-    '-O', '--output-file', help='specify output file (defaults to API_NAME.zip)', default=None
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
+@click.option(
+    "-O",
+    "--output-file",
+    help="specify output file (defaults to API_NAME.zip)",
+    default=None,
 )
 def export(*args, **kwargs):
     _export_api_proxy(*args, **kwargs)
 
 
-def _get_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
+def _get_api_proxy(
+    username, password, mfa_secret, token, zonename, org, profile, name, **kwargs
+):
     return (
         Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
         .get_api_proxy(name)
@@ -172,12 +197,12 @@ def _get_api_proxy(username, password, mfa_secret, token, zonename, org, profile
 
 
 @apis.command(
-    help='Gets an API proxy by name, including a list of existing revisions of the proxy.'
+    help="Gets an API proxy by name, including a list of existing revisions of the proxy."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-n", "--name", help="name", required=True)
 def get(*args, **kwargs):
     console.echo(_get_api_proxy(*args, **kwargs))
 
@@ -191,16 +216,16 @@ def _list_api_proxies(
     org,
     profile,
     prefix=None,
-    format='json',
+    format="json",
     **kwargs,
 ):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).list_api_proxies(
-        prefix=prefix
-    )
+    return Apis(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).list_api_proxies(prefix=prefix)
 
 
 @apis.command(
-    help='Gets the names of all API proxies in an organization. The names correspond to the names defined in the configuration files for each API proxy.'
+    help="Gets the names of all API proxies in an organization. The names correspond to the names defined in the configuration files for each API proxy."
 )
 @common_auth_options
 @common_verbose_options
@@ -220,11 +245,11 @@ def _list_api_proxy_revisions(
     )
 
 
-@apis.command(help='List all revisions for an API proxy.')
+@apis.command(help="List all revisions for an API proxy.")
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-n", "--name", help="name", required=True)
 def list_revisions(*args, **kwargs):
     console.echo(_list_api_proxy_revisions(*args, **kwargs))
 
@@ -249,13 +274,15 @@ def _undeploy_api_proxy_revision(
     )
 
 
-@apis.command(help='Undeploys an API proxy revision from an environment.')
+@apis.command(help="Undeploys an API proxy revision from an environment.")
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-e', '--environment', help='environment', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option("-e", "--environment", help="environment", required=True)
+@click.option(
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
 def undeploy_revision(*args, **kwargs):
     console.echo(_undeploy_api_proxy_revision(*args, **kwargs))
 
@@ -280,13 +307,17 @@ def _force_undeploy_api_proxy_revision(
     )
 
 
-@apis.command(help='Force the undeployment of the API proxy that is partially deployed.')
+@apis.command(
+    help="Force the undeployment of the API proxy that is partially deployed."
+)
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-e', '--environment', help='environment', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option("-e", "--environment", help="environment", required=True)
+@click.option(
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
 def force_undeploy_revision(*args, **kwargs):
     console.echo(_force_undeploy_api_proxy_revision(*args, **kwargs))
 
@@ -303,42 +334,46 @@ def _pull(
     revision_number,
     environment,
     work_tree,
-    dependencies=[],
+    # dependencies=[],
     force=False,
-    prefix=None,
-    basepath=None,
+    # prefix=None,
+    # basepath=None,
     **kwargs,
 ):
-    return Apis(
+    return PullApis(
         gen_auth(username, password, mfa_secret, token, zonename),
         org,
         revision_number,
         environment,
         work_tree=work_tree,
-    ).pull(name, force=force, prefix=prefix, basepath=basepath)
+        # ).pull(name, force=force, prefix=prefix, basepath=basepath)
+    ).pull(name, force=force)
 
 
 @apis.command(
-    help='Downloads an API proxy revision, along with any referenced key/value maps, target servers and caches into the current working directory.'
+    help="Downloads an API proxy revision, along with any referenced key/value maps, target servers and caches into the current working directory."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
-@click.option('-e', '--environment', help='environment', required=True)
+@click.option("-n", "--name", help="name", required=True)
 @click.option(
-    '--work-tree', help='set the path to the working tree (defaults to current working directory)'
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
 )
-@click.option('--force/--no-force', '-f/-F', default=False, help='force write files')
+@click.option("-e", "--environment", help="environment", required=True)
 @click.option(
-    '--prefix',
-    help='prefix to prepend to names. WARNING: this is not foolproof. make sure to review the changes.',
-    hidden=True,
-)
-@click.option(
-    '-b', '--basepath', help='set default basepath in apiproxy/proxies/default.xml', hidden=True
+    "--work-tree",
+    help="set the path to the working tree (defaults to current working directory)",
 )
+@click.option("--force/--no-force", "-f/-F", default=False, help="force write files")
+# @click.option(
+#     '--prefix',
+#     help='prefix to prepend to names. WARNING: this is not foolproof. make sure to review the changes.',
+#     hidden=True,
+# )
+# @click.option(
+#     '-b', '--basepath', help='set default basepath in apiproxy/proxies/default.xml', hidden=True
+# )
 def pull(*args, **kwargs):
     _pull(*args, **kwargs)
 
@@ -393,26 +428,31 @@ These files are Copyright 2015 Apigee Corporation, released under the Apache2 Li
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-e', '--environment', help='environment', required=True)
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-e", "--environment", help="environment", required=True)
+@click.option("-n", "--name", help="name", required=True)
 @click.option(
-    '-d',
-    '--directory',
-    help='directory with the apiproxy/ bundle',
+    "-d",
+    "--directory",
+    help="directory with the apiproxy/ bundle",
     type=click.Path(exists=True, dir_okay=True, file_okay=False, resolve_path=False),
     required=True,
 )
 @optgroup.group(
-    'Deployment options', cls=MutuallyExclusiveOptionGroup, help='The deployment options'
+    "Deployment options",
+    cls=MutuallyExclusiveOptionGroup,
+    help="The deployment options",
 )
 @optgroup.option(
-    '--import-only/--no-import-only', '-i/-I', default=False, help='import only and not deploy'
-)
-@optgroup.option(
-    '--seamless-deploy/--no-seamless-deploy',
-    '-s/-S',
+    "--import-only/--no-import-only",
+    "-i/-I",
     default=False,
-    help='seamless deploy the bundle',
+    help="import only and not deploy",
+)
+@optgroup.option(
+    "--seamless-deploy/--no-seamless-deploy",
+    "-s/-S",
+    default=False,
+    help="seamless deploy the bundle",
 )
 def deploy(*args, **kwargs):
     _deploy(*args, **kwargs)
