@@ -4,19 +4,30 @@ from click_option_group import MutuallyExclusiveOptionGroup, optgroup
 from apigee import console
 from apigee.apps.apps import Apps
 from apigee.auth import common_auth_options, gen_auth
+
 # from apigee.cls import OptionEatAll
 from apigee.prefix import common_prefix_options
 from apigee.silent import common_silent_options
 from apigee.verbose import common_verbose_options
 
 
-@click.group(help='Management APIs available for working with developer apps.')
+@click.group(help="Management APIs available for working with developer apps.")
 def apps():
     pass
 
 
 def _create_developer_app(
-    username, password, mfa_secret, token, zonename, org, profile, name, developer, body, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    developer,
+    body,
+    **kwargs
 ):
     return (
         Apps(gen_auth(username, password, mfa_secret, token, zonename), org, None)
@@ -26,20 +37,29 @@ def _create_developer_app(
 
 
 @apps.command(
-    help='Creates an app associated with a developer, associates the app with an API product, and auto-generates an API key for the app to use in calls to API proxies inside the API product.'
+    help="Creates an app associated with a developer, associates the app with an API product, and auto-generates an API key for the app to use in calls to API proxies inside the API product."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('--developer', help='developer email or id', required=True)
-@click.option('-b', '--body', help='request body', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
+@click.option("-b", "--body", help="request body", required=True)
 def create(*args, **kwargs):
     console.echo(_create_developer_app(*args, **kwargs))
 
 
 def _delete_developer_app(
-    username, password, mfa_secret, token, zonename, org, profile, name, developer, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    developer,
+    **kwargs
 ):
     return (
         Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
@@ -48,12 +68,12 @@ def _delete_developer_app(
     )
 
 
-@apps.command(help='Deletes a developer app.')
+@apps.command(help="Deletes a developer app.")
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('--developer', help='developer email or id', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
 def delete(*args, **kwargs):
     console.echo(_delete_developer_app(*args, **kwargs))
 
@@ -74,33 +94,44 @@ def _create_empty_developer_app(
 ):
     return (
         Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
-        .create_empty_developer_app(developer, display_name=display_name, callback_url=callback_url)
+        .create_empty_developer_app(
+            developer, display_name=display_name, callback_url=callback_url
+        )
         .text
     )
 
 
-@apps.command(help='Creates an empty developer app.')
+@apps.command(help="Creates an empty developer app.")
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('--developer', help='developer email or id', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
 @click.option(
-    '--display-name',
+    "--display-name",
     default=None,
     help="The DisplayName (set with an attribute) is what appears in the management UI. If you don't provide a DisplayName, the name is used.",
 )
 @click.option(
-    '--callback-url',
+    "--callback-url",
     default=None,
-    help='The callbackUrl is used by OAuth 2.0 authorization servers to communicate authorization codes back to apps. CallbackUrl must match the value of redirect_uri in some OAuth 2.0 See the documentation on OAuth 2.0 for more details.',
+    help="The callbackUrl is used by OAuth 2.0 authorization servers to communicate authorization codes back to apps. CallbackUrl must match the value of redirect_uri in some OAuth 2.0 See the documentation on OAuth 2.0 for more details.",
 )
 def create_empty(*args, **kwargs):
     console.echo(_create_empty_developer_app(*args, **kwargs))
 
 
 def _get_developer_app_details(
-    username, password, mfa_secret, token, zonename, org, profile, name, developer, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    developer,
+    **kwargs
 ):
     return (
         Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
@@ -110,17 +141,54 @@ def _get_developer_app_details(
 
 
 @apps.command(
-    help='Get the profile of a specific developer app. All times in the response are UNIX times. Note that the response contains a top-level attribute named accessType that is no longer used by Apigee.'
+    help="Get the profile of a specific developer app. All times in the response are UNIX times. Note that the response contains a top-level attribute named accessType that is no longer used by Apigee."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('--developer', help='developer email or id', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
 def get(*args, **kwargs):
     console.echo(_get_developer_app_details(*args, **kwargs))
 
 
+def _list_org_apps(
+    username, password, mfa_secret, token, zonename, org, profile, **kwargs
+):
+    return (
+        Apps(gen_auth(username, password, mfa_secret, token, zonename), org, None)
+        .list_org_apps()
+        .text
+    )
+
+
+@apps.command(help="Lists apps in an organisation.")
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+def list_org_apps(*args, **kwargs):
+    console.echo(_list_org_apps(*args, **kwargs))
+
+
+def _get_org_app(
+    username, password, mfa_secret, token, zonename, org, profile, name, **kwargs
+):
+    return (
+        Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .get_org_app()
+        .text
+    )
+
+
+@apps.command(help="Gets an app in an organisation.")
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+@click.option("-n", "--name", help="name", required=True)
+def get_org_app(*args, **kwargs):
+    console.echo(_get_org_app(*args, **kwargs))
+
+
 def _list_developer_apps(
     username,
     password,
@@ -138,7 +206,9 @@ def _list_developer_apps(
 ):
     return Apps(
         gen_auth(username, password, mfa_secret, token, zonename), org, None
-    ).list_developer_apps(developer, prefix=prefix, expand=expand, count=count, startkey=startkey)
+    ).list_developer_apps(
+        developer, prefix=prefix, expand=expand, count=count, startkey=startkey
+    )
 
 
 @apps.command(
@@ -148,24 +218,24 @@ def _list_developer_apps(
 @common_verbose_options
 @common_silent_options
 @common_prefix_options
-@click.option('--developer', help='developer email or id', required=True)
+@click.option("--developer", help="developer email or id", required=True)
 @click.option(
-    '--expand/--no-expand',
+    "--expand/--no-expand",
     default=False,
-    help='Set to true to expand the results. This query parameter does not work if you use the count or startKey query parameters.',
+    help="Set to true to expand the results. This query parameter does not work if you use the count or startKey query parameters.",
 )
 @click.option(
-    '--count',
+    "--count",
     type=click.INT,
     default=1000,
     show_default=True,
-    help='Limits the list to the number you specify. The limit is 100. Use with the startKey parameter to provide more targeted filtering.',
+    help="Limits the list to the number you specify. The limit is 100. Use with the startKey parameter to provide more targeted filtering.",
 )
 @click.option(
-    '--startkey',
+    "--startkey",
     default="",
     show_default=True,
-    help='To filter the keys that are returned, enter the name of a developer app that the list will start with.',
+    help="To filter the keys that are returned, enter the name of a developer app that the list will start with.",
 )
 def list(*args, **kwargs):
     console.echo(_list_developer_apps(*args, **kwargs))
@@ -182,8 +252,83 @@ def list(*args, **kwargs):
 # ):
 #     pass
 
-# def _delete_key_for_a_developer_app(username, password, mfa_secret, token, zonename, org, profile, developer, consumer_key):
-#     pass
+
+def _delete_key_for_a_developer_app(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    developer,
+    consumer_key=None,
+    **kwargs
+):
+    return (
+        Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .delete_key_for_a_developer_app(developer, consumer_key=consumer_key,)
+        .text
+    )
+
+
+@apps.command(help="Deletes a custom consumer key from a developer app.")
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+@click.option("-n", "--name", help="app name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
+@click.option("--consumer-key", help="consumer key", required=True)
+def delete_creds(*args, **kwargs):
+    console.echo(_delete_key_for_a_developer_app(*args, **kwargs))
+
+
+def _update_key_for_a_developer_app(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    developer,
+    consumer_key=None,
+    action="",
+    **kwargs
+):
+    return (
+        Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .update_key_for_a_developer_app(
+            developer, consumer_key=consumer_key, action=action,
+        )
+        .text
+    )
+
+
+@apps.command(help="Approve a custom consumer key in a developer app.")
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+@click.option("-n", "--name", help="app name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
+@click.option("--consumer-key", help="consumer key", required=True)
+@click.option("--action", default="approve", hidden=True)
+def approve_creds(*args, **kwargs):
+    console.echo(_update_key_for_a_developer_app(*args, **kwargs))
+
+
+@apps.command(help="Revoke a custom consumer key in a developer app.")
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+@click.option("-n", "--name", help="app name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
+@click.option("--consumer-key", help="consumer key", required=True)
+@click.option("--action", default="revoke", hidden=True)
+def revoke_creds(*args, **kwargs):
+    console.echo(_update_key_for_a_developer_app(*args, **kwargs))
 
 
 def _create_a_consumer_key_and_secret(
@@ -201,7 +346,7 @@ def _create_a_consumer_key_and_secret(
     key_length=32,
     secret_length=32,
     key_suffix=None,
-    key_delimiter='-',
+    key_delimiter="-",
     products=[],
     **kwargs
 ):
@@ -222,37 +367,47 @@ def _create_a_consumer_key_and_secret(
 
 
 @apps.command(
-    help='Creates a custom consumer key and secret for a developer app. This is particularly useful if you want to migrate existing consumer keys/secrets to Edge from another system. Consumer keys and secrets can contain letters, numbers, underscores, and hyphens. No other special characters are allowed.'
+    help="Creates a custom consumer key and secret for a developer app. This is particularly useful if you want to migrate existing consumer keys/secrets to Edge from another system. Consumer keys and secrets can contain letters, numbers, underscores, and hyphens. No other special characters are allowed."
 )
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option('-n', '--name', help='app name', required=True)
-@click.option('--developer', help='developer email or id', required=True)
+@click.option("-n", "--name", help="app name", required=True)
+@click.option("--developer", help="developer email or id", required=True)
 @optgroup.group(
-    'consumerKey options', cls=MutuallyExclusiveOptionGroup, help='The consumerKey options'
+    "consumerKey options",
+    cls=MutuallyExclusiveOptionGroup,
+    help="The consumerKey options",
 )
-@optgroup.option('--consumer-key', default=None, help="")
+@optgroup.option("--consumer-key", default=None, help="")
 @optgroup.option(
-    '--key-length', type=click.INT, default=32, show_default=True, help='length of the consumer key'
-)
-@optgroup.group(
-    'consumerSecret options', cls=MutuallyExclusiveOptionGroup, help='The consumerSecret options'
-)
-@optgroup.option('--consumer-secret', default=None, help="")
-@optgroup.option(
-    '--secret-length',
+    "--key-length",
     type=click.INT,
     default=32,
     show_default=True,
-    help='length of the consumer secret',
+    help="length of the consumer key",
 )
-@click.option('--key-suffix', default=None, help="")
+@optgroup.group(
+    "consumerSecret options",
+    cls=MutuallyExclusiveOptionGroup,
+    help="The consumerSecret options",
+)
+@optgroup.option("--consumer-secret", default=None, help="")
+@optgroup.option(
+    "--secret-length",
+    type=click.INT,
+    default=32,
+    show_default=True,
+    help="length of the consumer secret",
+)
+@click.option("--key-suffix", default=None, help="")
 @click.option(
-    '--key-delimiter', default='-', help='separates consumerKey and key suffix with a delimiter.'
+    "--key-delimiter",
+    default="-",
+    help="separates consumerKey and key suffix with a delimiter.",
 )
 @click.option(
-    '--products',
+    "--products",
     multiple=True,
     default=[],
     show_default=True,
@@ -276,7 +431,9 @@ def create_creds(*args, **kwargs):
 #     pass
 
 
-def _restore_app(username, password, mfa_secret, token, zonename, org, profile, file, **kwargs):
+def _restore_app(
+    username, password, mfa_secret, token, zonename, org, profile, file, **kwargs
+):
     return (
         Apps(gen_auth(username, password, mfa_secret, token, zonename), org, None)
         .restore_app(file)
@@ -284,13 +441,13 @@ def _restore_app(username, password, mfa_secret, token, zonename, org, profile,
     )
 
 
-@apps.command(help='Restore developer app from a file.')
+@apps.command(help="Restore developer app from a file.")
 @common_auth_options
 @common_silent_options
 @common_verbose_options
 @click.option(
-    '-f',
-    '--file',
+    "-f",
+    "--file",
     type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False),
     required=True,
 )
