@@ -7,41 +7,33 @@ from apigee import APIGEE_ADMIN_API_URL, auth, console
 from apigee.keystores.serializer import KeystoresSerializer
 
 CREATE_A_KEYSTORE_OR_TRUSTSTORE_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores'
+    "{api_url}/v1/o/{org_name}/environments/{environment}/keystores"
 )
 DELETE_A_KEYSTORE_OR_TRUSTSTORE_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}'
+    "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}"
 )
 LIST_ALL_KEYSTORES_AND_TRUSTSTORES_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores'
+    "{api_url}/v1/o/{org_name}/environments/{environment}/keystores"
 )
 GET_A_KEYSTORE_OR_TRUSTSTORE_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}'
+    "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}"
 )
-TEST_A_KEYSTORE_OR_TRUSTSTORE_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/testssl'
-GET_CERT_DETAILS_FROM_A_KEYSTORE_OR_TRUSTSTORE_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs/{cert_name}'
-GET_ALL_CERTS_FROM_A_KEYSTORE_OR_TRUSTSTORE_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs'
+TEST_A_KEYSTORE_OR_TRUSTSTORE_PATH = (
+    "{api_url}/v1/o/{org_name}/environments/{environment}/testssl"
 )
-DELETE_CERT_FROM_A_KEYSTORE_OR_TRUSTSTORE_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs/{cert_name}'
-EXPORT_A_CERT_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs/{cert_name}/export'
-UPLOAD_A_CERTIFICATE_TO_A_TRUSTSTORE_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs'
-)
-UPLOAD_A_JAR_FILE_TO_A_KEYSTORE_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/keys'
-)
-CREATE_AN_ALIAS_BY_GENERATING_A_SELF_SIGNED_CERTIFICATE_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases'
-)
-LIST_ALIASES_PATH = (
-    '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases'
-)
-GET_ALIAS_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}'
-UPDATE_THE_CERTIFICATE_IN_AN_ALIAS_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}'
-GENERATE_A_CSR_FOR_AN_ALIAS_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}/csr'
-EXPORT_A_CERTIFICATE_FOR_AN_ALIAS_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}/certificate'
-DELETE_ALIAS_PATH = '{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}'
+GET_CERT_DETAILS_FROM_A_KEYSTORE_OR_TRUSTSTORE_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs/{cert_name}"
+GET_ALL_CERTS_FROM_A_KEYSTORE_OR_TRUSTSTORE_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs"
+DELETE_CERT_FROM_A_KEYSTORE_OR_TRUSTSTORE_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs/{cert_name}"
+EXPORT_A_CERT_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs/{cert_name}/export"
+UPLOAD_A_CERTIFICATE_TO_A_TRUSTSTORE_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/certs"
+UPLOAD_A_JAR_FILE_TO_A_KEYSTORE_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/keys"
+CREATE_AN_ALIAS_BY_GENERATING_A_SELF_SIGNED_CERTIFICATE_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases"
+LIST_ALIASES_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases"
+GET_ALIAS_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}"
+UPDATE_THE_CERTIFICATE_IN_AN_ALIAS_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}"
+GENERATE_A_CSR_FOR_AN_ALIAS_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}/csr"
+EXPORT_A_CERTIFICATE_FOR_AN_ALIAS_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}/certificate"
+DELETE_ALIAS_PATH = "{api_url}/v1/o/{org_name}/environments/{environment}/keystores/{keystore_name}/aliases/{alias_name}"
 
 
 class Keystores:
@@ -83,11 +75,15 @@ class Keystores:
     def delete_a_keystore_or_truststore(self):
         pass
 
-    def list_all_keystores_and_truststores(self, environment, prefix=None, format='json'):
+    def list_all_keystores_and_truststores(
+        self, environment, prefix=None, format="json"
+    ):
         uri = LIST_ALL_KEYSTORES_AND_TRUSTSTORES_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org_name=self._org_name, environment=environment
+            api_url=APIGEE_ADMIN_API_URL,
+            org_name=self._org_name,
+            environment=environment,
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return KeystoresSerializer().serialize_details(resp, format, prefix=prefix)
@@ -99,7 +95,7 @@ class Keystores:
             environment=environment,
             keystore_name=self._keystore_name,
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
@@ -115,19 +111,21 @@ class Keystores:
             keystore_name=self._keystore_name,
             cert_name=cert_name,
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
-    def get_all_certs_from_a_keystore_or_truststore(self, environment, prefix=None, format='json'):
+    def get_all_certs_from_a_keystore_or_truststore(
+        self, environment, prefix=None, format="json"
+    ):
         uri = GET_ALL_CERTS_FROM_A_KEYSTORE_OR_TRUSTSTORE_PATH.format(
             api_url=APIGEE_ADMIN_API_URL,
             org_name=self._org_name,
             environment=environment,
             keystore_name=self._keystore_name,
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return KeystoresSerializer().serialize_details(resp, format, prefix=prefix)
@@ -157,14 +155,14 @@ class Keystores:
     def create_an_alias_by_generating_a_self_signed_certificate(self):
         pass
 
-    def list_aliases(self, environment, prefix=None, format='json'):
+    def list_aliases(self, environment, prefix=None, format="json"):
         uri = LIST_ALIASES_PATH.format(
             api_url=APIGEE_ADMIN_API_URL,
             org_name=self._org_name,
             environment=environment,
             keystore_name=self._keystore_name,
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return KeystoresSerializer().serialize_details(resp, format, prefix=prefix)
@@ -177,7 +175,7 @@ class Keystores:
             keystore_name=self._keystore_name,
             alias_name=alias_name,
         )
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
