@@ -9,11 +9,46 @@ from apigee.silent import common_silent_options
 from apigee.verbose import common_verbose_options
 
 
-@click.group(help='You can use the following APIs to manage shared flows and flow hooks.')
+@click.group(
+    help="You can use the following APIs to manage shared flows and flow hooks."
+)
 def sharedflows():
     pass
 
 
+def _delete_a_shared_flow_revision(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    revision_number,
+    **kwargs,
+):
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .delete_a_shared_flow_revision(name, revision_number)
+        .text
+    )
+
+
+@sharedflows.command(
+    help="Deletes a revision of a shared flow and all policies, resources, endpoints, and revisions associated with it. The shared flow revision must be undeployed before you can delete it."
+)
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+@click.option("-n", "--name", help="name", required=True)
+@click.option(
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
+def delete_revision(*args, **kwargs):
+    console.echo(_delete_a_shared_flow_revision(*args, **kwargs))
+
+
 def _get_a_list_of_shared_flows(
     username, password, mfa_secret, token, zonename, org, profile, prefix=None, **kwargs
 ):
@@ -23,7 +58,7 @@ def _get_a_list_of_shared_flows(
 
 
 @sharedflows.command(
-    help='Gets an array of the names of shared flows in the organization. The response is a simple array of strings.'
+    help="Gets an array of the names of shared flows in the organization. The response is a simple array of strings."
 )
 @common_auth_options
 @common_prefix_options
@@ -44,21 +79,21 @@ def _import_a_shared_flow(
 
 
 @sharedflows.command(
-    name='import',
-    help='Uploads a ZIP-formatted shared flow configuration bundle from a local machine to an Edge organization. If the shared flow already exists, this creates a new revision of it. If the shared flow does not exist, this creates it. Once imported, the shared flow revision must be deployed before it can be accessed at runtime. By default, shared flow configurations are not validated on import.',
+    name="import",
+    help="Uploads a ZIP-formatted shared flow configuration bundle from a local machine to an Edge organization. If the shared flow already exists, this creates a new revision of it. If the shared flow does not exist, this creates it. Once imported, the shared flow revision must be deployed before it can be accessed at runtime. By default, shared flow configurations are not validated on import.",
 )
 @common_auth_options
 @common_prefix_options
 @common_silent_options
 @common_verbose_options
 @click.option(
-    '-f',
-    '--file',
+    "-f",
+    "--file",
     type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False),
     required=True,
-    help='file path of the shared flow configuration in ZIP format',
+    help="file path of the shared flow configuration in ZIP format",
 )
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-n", "--name", help="name", required=True)
 def import_a_shared_flow(*args, **kwargs):
     console.echo(_import_a_shared_flow(*args, **kwargs))
 
@@ -77,11 +112,13 @@ def _get_a_shared_flow(
     )
 
 
-@sharedflows.command(help='Gets a shared flow by name, including a list of its revisions.')
+@sharedflows.command(
+    help="Gets a shared flow by name, including a list of its revisions."
+)
 @common_auth_options
 @common_silent_options
 @common_verbose_options
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-n", "--name", help="name", required=True)
 def get(*args, **kwargs):
     console.echo(_get_a_shared_flow(*args, **kwargs))
 
@@ -100,7 +137,7 @@ def _deploy_a_shared_flow(
     override,
     delay,
     file,
-    **kwargs
+    **kwargs,
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -117,36 +154,38 @@ def _deploy_a_shared_flow(
 
 
 @sharedflows.command(
-    help='Deploys a shared flow revision to an environment in an organization. Shared flows cannot be used until they have been deployed to an environment. If you experience HTTP 500 errors during deployment, consider using the override parameter to deploy the shared flow in place of a revision currently deployed. The size limit of a shared flow bundle is 15 MB.'
+    help="Deploys a shared flow revision to an environment in an organization. Shared flows cannot be used until they have been deployed to an environment. If you experience HTTP 500 errors during deployment, consider using the override parameter to deploy the shared flow in place of a revision currently deployed. The size limit of a shared flow bundle is 15 MB."
 )
 @common_auth_options
 @common_prefix_options
 @common_silent_options
 @common_verbose_options
-@click.option('-e', '--environment', help='environment', required=True)
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-e", "--environment", help="environment", required=True)
+@click.option("-n", "--name", help="name", required=True)
 @optgroup.group(
-    'Deployment options', cls=RequiredMutuallyExclusiveOptionGroup, help='The deployment options'
+    "Deployment options",
+    cls=RequiredMutuallyExclusiveOptionGroup,
+    help="The deployment options",
 )
 @optgroup.option(
-    '-f',
-    '--file',
+    "-f",
+    "--file",
     type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False),
-    help='file path of the shared flow configuration in ZIP format',
+    help="file path of the shared flow configuration in ZIP format",
 )
-@optgroup.option('-r', '--revision-number', type=click.INT, help='revision number')
+@optgroup.option("-r", "--revision-number", type=click.INT, help="revision number")
 @click.option(
-    '--override/--no-override',
+    "--override/--no-override",
     default=False,
     show_default=True,
     help='Set this flag to "true" to deploy the shared flow revision in place of the revision currently deployed (also known as "zero downtime" deployment).',
 )
 @click.option(
-    '--delay',
+    "--delay",
     type=click.INT,
     default=0,
     show_default=True,
-    help='Enforces a delay, measured in seconds, before the currently deployed API proxy revision is undeployed and replaced by the new revision that is being deployed. Use this setting to minimize the impact of deployment on in-flight transactions. The default value is 0.',
+    help="Enforces a delay, measured in seconds, before the currently deployed API proxy revision is undeployed and replaced by the new revision that is being deployed. Use this setting to minimize the impact of deployment on in-flight transactions. The default value is 0.",
 )
 def deploy(*args, **kwargs):
     console.echo(_deploy_a_shared_flow(*args, **kwargs))
@@ -163,7 +202,7 @@ def _undeploy_a_shared_flow(
     environment,
     name,
     revision_number,
-    **kwargs
+    **kwargs,
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -172,19 +211,30 @@ def _undeploy_a_shared_flow(
     )
 
 
-@sharedflows.command(help='Undeploys a shared flow revision from an environment.')
+@sharedflows.command(help="Undeploys a shared flow revision from an environment.")
 @common_auth_options
 @common_silent_options
 @common_verbose_options
-@click.option('-e', '--environment', help='environment', required=True)
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
+@click.option("-e", "--environment", help="environment", required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option(
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
 def undeploy(*args, **kwargs):
     console.echo(_undeploy_a_shared_flow(*args, **kwargs))
 
 
 def _get_deployment_environments_for_shared_flows(
-    username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    revision_number,
+    **kwargs,
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -193,16 +243,60 @@ def _get_deployment_environments_for_shared_flows(
     )
 
 
-@sharedflows.command(help='Gets an array of the environments to which the shared flow is deployed.')
+@sharedflows.command(
+    help="Gets an array of the environments to which the shared flow is deployed."
+)
 @common_auth_options
 @common_silent_options
 @common_verbose_options
-@click.option('-n', '--name', help='name', required=True)
-@click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
+@click.option("-n", "--name", help="name", required=True)
+@click.option(
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
 def get_deployment_environments(*args, **kwargs):
     console.echo(_get_deployment_environments_for_shared_flows(*args, **kwargs))
 
 
+def _delete_undeployed_revisions(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    save_last=0,
+    dry_run=False,
+    **kwargs,
+):
+    return Sharedflows(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).delete_undeployed_revisions(name, save_last=save_last, dry_run=dry_run)
+
+
+@sharedflows.command(
+    help="Deletes all undeployed revisions of a shared flow and all policies, resources, endpoints, and revisions associated with it."
+)
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+@click.option("-n", "--name", help="name", required=True)
+@click.option(
+    "--save-last",
+    type=click.INT,
+    help="denotes not to delete the N most recent revisions",
+    default=0,
+)
+@click.option(
+    "--dry-run/--no-dry-run",
+    default=False,
+    help="show revisions to be deleted but do not delete",
+)
+def clean(*args, **kwargs):
+    _delete_undeployed_revisions(*args, **kwargs)
+
+
 def _delete_a_shared_flow(self, shared_flow_name):
     pass
 
@@ -215,7 +309,16 @@ def _delete_a_shared_flow(self, shared_flow_name):
 
 
 def _get_the_shared_flow_attached_to_a_flow_hook(
-    username, password, mfa_secret, token, zonename, org, profile, environment, flow_hook, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    environment,
+    flow_hook,
+    **kwargs,
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -230,8 +333,10 @@ def _get_the_shared_flow_attached_to_a_flow_hook(
 @common_auth_options
 @common_silent_options
 @common_verbose_options
-@click.option('-e', '--environment', help='environment', required=True)
-@click.option('--flow-hook', help='flow hook to which the shared flow is attached', required=True)
+@click.option("-e", "--environment", help="environment", required=True)
+@click.option(
+    "--flow-hook", help="flow hook to which the shared flow is attached", required=True
+)
 def get_flow_hook(*args, **kwargs):
     console.echo(_get_the_shared_flow_attached_to_a_flow_hook(*args, **kwargs))
 
@@ -246,11 +351,11 @@ def _get_shared_flow_deployments(
     )
 
 
-@sharedflows.command(help='View all shared flow deployments.')
+@sharedflows.command(help="View all shared flow deployments.")
 @common_auth_options
 @common_silent_options
 @common_verbose_options
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-n", "--name", help="name", required=True)
 def get_deployments(*args, **kwargs):
     console.echo(_get_shared_flow_deployments(*args, **kwargs))
 
@@ -265,10 +370,55 @@ def _get_shared_flow_revisions(
     )
 
 
-@sharedflows.command(help='List the revisions of a shared flow.')
+@sharedflows.command(help="List the revisions of a shared flow.")
 @common_auth_options
 @common_silent_options
 @common_verbose_options
-@click.option('-n', '--name', help='name', required=True)
+@click.option("-n", "--name", help="name", required=True)
 def get_revisions(*args, **kwargs):
     console.echo(_get_shared_flow_revisions(*args, **kwargs))
+
+
+def _export_shared_flow(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    revision_number,
+    fs_write=True,
+    output_file=None,
+    **kwargs,
+):
+    return Sharedflows(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).export_shared_flow(
+        name,
+        revision_number,
+        output_file if output_file else f"{name}.zip",
+        fs_write=True,
+    )
+
+
+@sharedflows.command(
+    help="Outputs a shared flow revision as a ZIP formatted bundle of code and config files. This enables local configuration and development, including attachment of policies and scripts."
+)
+@common_auth_options
+@common_verbose_options
+@common_silent_options
+@click.option("-n", "--name", help="name", required=True)
+@click.option(
+    "-r", "--revision-number", type=click.INT, help="revision number", required=True
+)
+@click.option(
+    "-O",
+    "--output-file",
+    type=click.Path(exists=False, dir_okay=False, file_okay=True, resolve_path=False),
+    help="specify output file (defaults to SHARED_FLOW_NAME.zip)",
+    default=None,
+)
+def export(*args, **kwargs):
+    _export_shared_flow(*args, **kwargs)
