@@ -4,29 +4,34 @@ import requests
 from requests.exceptions import HTTPError
 
 from apigee import APIGEE_ADMIN_API_URL, auth, console
+from apigee.deployments.deployments import Deployments
 from apigee.sharedflows.serializer import SharedflowsSerializer
-from apigee.utils import add_to_dict_if_exists
+from apigee.utils import add_to_dict_if_exists, run_func_on_iterable, write_zip
 
-GET_A_LIST_OF_SHARED_FLOWS_PATH = '{api_url}/v1/organizations/{org}/sharedflows'
-IMPORT_A_SHARED_FLOW_PATH = '{api_url}/v1/organizations/{org}/sharedflows'
+GET_A_LIST_OF_SHARED_FLOWS_PATH = "{api_url}/v1/organizations/{org}/sharedflows"
+IMPORT_A_SHARED_FLOW_PATH = "{api_url}/v1/organizations/{org}/sharedflows"
 # EXPORT_A_SHARED_FLOW_PATH = ''
-GET_A_SHARED_FLOW_PATH = '{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}'
-DEPLOY_A_SHARED_FLOW_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/sharedflows/{shared_flow_name}/revisions/{revision_number}/deployments'
-UNDEPLOY_SHARED_FLOW_REVISIONS_IN_ENVIRONMENT_PATH = ''
-UNDEPLOY_A_SHARED_FLOW_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/sharedflows/{shared_flow_name}/revisions/{revision_number}/deployments'
-GET_DEPLOYMENT_ENVIRONMENTS_FOR_SHARED_FLOWS_PATH = '{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/revisions/{revision_number}/deployments'
-DELETE_A_SHARED_FLOW_PATH = ''
+GET_A_SHARED_FLOW_PATH = (
+    "{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}"
+)
+DEPLOY_A_SHARED_FLOW_PATH = "{api_url}/v1/organizations/{org}/environments/{environment}/sharedflows/{shared_flow_name}/revisions/{revision_number}/deployments"
+UNDEPLOY_SHARED_FLOW_REVISIONS_IN_ENVIRONMENT_PATH = ""
+UNDEPLOY_A_SHARED_FLOW_PATH = "{api_url}/v1/organizations/{org}/environments/{environment}/sharedflows/{shared_flow_name}/revisions/{revision_number}/deployments"
+GET_DEPLOYMENT_ENVIRONMENTS_FOR_SHARED_FLOWS_PATH = "{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/revisions/{revision_number}/deployments"
+DELETE_A_SHARED_FLOW_PATH = ""
+DELETE_A_SHARED_FLOW_REVISION_PATH = "{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/revisions/{revision_number}"
 # ATTACH_A_SHARED_FLOW_TO_A_FLOW_HOOK_PATH = ''
 # DETACHES_A_SHARED_FLOW_FROM_A_FLOW_HOOK_PATH = ''
 GET_THE_SHARED_FLOW_ATTACHED_TO_A_FLOW_HOOK_PATH = (
-    '{api_url}/v1/organizations/{org}/environments/{environment}/flowhooks/{flow_hook}'
+    "{api_url}/v1/organizations/{org}/environments/{environment}/flowhooks/{flow_hook}"
 )
 GET_SHARED_FLOW_DEPLOYMENTS_PATH = (
-    '{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/deployments'
+    "{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/deployments"
 )
 GET_SHARED_FLOW_REVISIONS_PATH = (
-    '{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/revisions'
+    "{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/revisions"
 )
+EXPORT_SHARED_FLOW_PATH = "{api_url}/v1/organizations/{org}/sharedflows/{shared_flow_name}/revisions/{revision_number}?format=bundle"
 
 
 class Sharedflows:
@@ -53,24 +58,60 @@ class Sharedflows:
     def org_name(self, value):
         self._org_name = value
 
+    def delete_a_shared_flow_revision(self, shared_flow_name, revision_number):
+        uri = DELETE_A_SHARED_FLOW_REVISION_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            shared_flow_name=shared_flow_name,
+            revision_number=revision_number,
+        )
+        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
+        resp = requests.delete(uri, headers=hdrs)
+        resp.raise_for_status()
+        return resp
+
+    def delete_undeployed_revisions(self, shared_flow_name, save_last=0, dry_run=False):
+        details = SharedflowsSerializer.filter_deployment_details(
+            Deployments(self._auth, self._org_name, shared_flow_name)
+            .get_shared_flow_deployment_details()
+            .json()
+        )
+        undeployed = SharedflowsSerializer.filter_undeployed_revisions(
+            self.get_shared_flow_revisions(shared_flow_name).json(),
+            SharedflowsSerializer.filter_deployed_revisions(details),
+            save_last=save_last,
+        )
+        console.echo(f"Undeployed revisions to be deleted: {undeployed}")
+        if dry_run:
+            return undeployed
+
+        def _func(revision):
+            console.echo(f"Deleting revison {revision}")
+            self.delete_a_shared_flow_revision(shared_flow_name, revision)
+
+        return run_func_on_iterable(undeployed, _func)
+
     def get_a_list_of_shared_flows(self, prefix=None):
         uri = GET_A_LIST_OF_SHARED_FLOWS_PATH.format(
             api_url=APIGEE_ADMIN_API_URL, org=self._org_name
         )
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
-        return SharedflowsSerializer().serialize_details(resp, 'json', prefix=prefix)
+        return SharedflowsSerializer.serialize_details(resp, "json", prefix=prefix)
 
     def import_a_shared_flow(self, shared_flow_file, shared_flow_name):
-        uri = IMPORT_A_SHARED_FLOW_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name)
-        hdrs = auth.set_header(
-            self._auth, {'Accept': 'application/json', 'Content-Type': 'multipart/form-data'}
+        uri = IMPORT_A_SHARED_FLOW_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name
         )
-        params = {'action': 'import', 'name': shared_flow_name}
-        with open(shared_flow_file, 'rb') as f:
+        hdrs = auth.set_header(
+            self._auth,
+            {"Accept": "application/json", "Content-Type": "multipart/form-data"},
+        )
+        params = {"action": "import", "name": shared_flow_name}
+        with open(shared_flow_file, "rb") as f:
             resp = requests.post(
-                uri, headers=hdrs, files={'file': ('sharedflow.zip', f)}, params=params
+                uri, headers=hdrs, files={"file": ("sharedflow.zip", f)}, params=params
             )
         resp.raise_for_status()
         return resp
@@ -80,9 +121,11 @@ class Sharedflows:
 
     def get_a_shared_flow(self, shared_flow_name):
         uri = GET_A_SHARED_FLOW_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, shared_flow_name=shared_flow_name
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            shared_flow_name=shared_flow_name,
         )
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
@@ -105,7 +148,9 @@ class Sharedflows:
                 raise e
         if shared_flow_file:
             revision_number = int(
-                self.import_a_shared_flow(shared_flow_file, shared_flow_name).json()['revision']
+                self.import_a_shared_flow(shared_flow_file, shared_flow_name).json()[
+                    "revision"
+                ]
             )
         uri = DEPLOY_A_SHARED_FLOW_PATH.format(
             api_url=APIGEE_ADMIN_API_URL,
@@ -114,13 +159,16 @@ class Sharedflows:
             shared_flow_name=shared_flow_name,
             revision_number=revision_number,
         )
-        options_dict = {'override': 'true' if override else 'false', 'delay': f'{delay}'}
+        options_dict = {
+            "override": "true" if override else "false",
+            "delay": f"{delay}",
+        }
         params = add_to_dict_if_exists(options_dict)
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
-        console.echo(f'Deploying revision {revision_number}... ', end='', flush=True)
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
+        console.echo(f"Deploying revision {revision_number}... ", end="", flush=True)
         resp = requests.post(uri, headers=hdrs, params=params)
         resp.raise_for_status()
-        console.echo('Done')
+        console.echo("Done")
         if do_deployments_exist:
             # console.echo('Attempting undeployment... ')
             self.undeploy_shared_flow_revisions_in_environment(
@@ -133,16 +181,20 @@ class Sharedflows:
         self, environment, shared_flow_name, except_revisions=set()
     ):
         resp = self.get_shared_flow_deployments(shared_flow_name)
-        for deployment in resp.json()['environment']:
-            if deployment['name'] == environment:
-                for detail in deployment['revision']:
-                    revision_number = int(detail['name'])
+        for deployment in resp.json()["environment"]:
+            if deployment["name"] == environment:
+                for detail in deployment["revision"]:
+                    revision_number = int(detail["name"])
                     if revision_number not in except_revisions:
                         console.echo(
-                            f'Undeploying revision {revision_number}... ', end='', flush=True
+                            f"Undeploying revision {revision_number}... ",
+                            end="",
+                            flush=True,
                         )
-                        self.undeploy_a_shared_flow(environment, shared_flow_name, revision_number)
-                        console.echo('Done')
+                        self.undeploy_a_shared_flow(
+                            environment, shared_flow_name, revision_number
+                        )
+                        console.echo("Done")
         return resp
 
     def undeploy_a_shared_flow(self, environment, shared_flow_name, revision_number):
@@ -153,19 +205,21 @@ class Sharedflows:
             shared_flow_name=shared_flow_name,
             revision_number=revision_number,
         )
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
-    def get_deployment_environments_for_shared_flows(self, shared_flow_name, revision_number):
+    def get_deployment_environments_for_shared_flows(
+        self, shared_flow_name, revision_number
+    ):
         uri = GET_DEPLOYMENT_ENVIRONMENTS_FOR_SHARED_FLOWS_PATH.format(
             api_url=APIGEE_ADMIN_API_URL,
             org=self._org_name,
             shared_flow_name=shared_flow_name,
             revision_number=revision_number,
         )
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
@@ -186,25 +240,45 @@ class Sharedflows:
             environment=environment,
             flow_hook=flow_hook,
         )
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def get_shared_flow_deployments(self, shared_flow_name):
         uri = GET_SHARED_FLOW_DEPLOYMENTS_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, shared_flow_name=shared_flow_name
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            shared_flow_name=shared_flow_name,
         )
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def get_shared_flow_revisions(self, shared_flow_name):
         uri = GET_SHARED_FLOW_REVISIONS_PATH.format(
-            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, shared_flow_name=shared_flow_name
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            shared_flow_name=shared_flow_name,
         )
-        hdrs = auth.set_header(self._auth, {'Accept': 'application/json'})
+        hdrs = auth.set_header(self._auth, {"Accept": "application/json"})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
+
+    def export_shared_flow(
+        self, shared_flow_name, revision_number, output_file, fs_write=True
+    ):
+        uri = EXPORT_SHARED_FLOW_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            shared_flow_name=shared_flow_name,
+            revision_number=revision_number,
+        )
+        hdrs = auth.set_header(self._auth)
+        resp = requests.get(uri, headers=hdrs)
+        resp.raise_for_status()
+        if fs_write and output_file:
+            write_zip(output_file, resp.content)
+        return resp
